@@ -100,7 +100,7 @@ void command_save(gpointer callback_data,guint callback_action,
 	} else {
 		text=g_strdup_printf(_("%s\nThis file is existed.\n\nOver write?"),
 																tmaid->file);
-		if ((!tmaid->overwrite || !misc_isfile(tmaid->file)
+		if ((!tmaid->ft.overwrite || !misc_isfile(tmaid->file)
 			|| misc_message_box("Text maid",text,1,_("_Yes"),_("_No"),NULL)==0)
 										&& file_save_text(tmaid->file,tmaid)) {
 			tmaid_change_edit (tmaid, FALSE);
@@ -137,7 +137,7 @@ void command_saveas(gpointer callback_data,guint callback_action,
 	if (file!=NULL) {
 		text=g_strdup_printf(_("%s\nThis file is existed.\n\nOver write?"),
 																		file);
-		if ((!tmaid->overwrite || !misc_isfile(file)
+		if ((!tmaid->ft.overwrite || !misc_isfile(file)
 			|| misc_message_box("Text maid",text,1,_("_Yes"),_("_No"),NULL)==0)
 											&& file_save_text(file,tmaid)) {
 			g_free(save_path);
@@ -237,7 +237,7 @@ void command_print(gpointer callback_data,guint callback_action,
 				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
 	printer.select=tmaid->select.x>=0;
-	printer.column=tmaid->margin;
+	printer.column=tmaid->ft.margin;
 	printer.font_width=tmaid->font_width;
 	printer.font_height=tmaid->font_height;
 	if (print_dialog(&printer))
@@ -257,56 +257,25 @@ void command_property(gpointer callback_data,guint callback_action,
 	tmaid=gtk_object_get_user_data(GTK_OBJECT(
 				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
-	ft.ft_id=tmaid->ft_id;
-	ft.margin=tmaid->margin;
-	ft.tab=tmaid->tab;
-	ft.autoindent=tmaid->autoindent;
-	ft.crlf=tmaid->crlf;
-	ft.eof=tmaid->eof;
-	ft.limit=tmaid->limit;
-	ft.overwrite=tmaid->overwrite;
-	ft.space=tmaid->space;
-	ft.syscol=tmaid->syscol;
-	ft.gline=tmaid->gline;
-	ft.mline=tmaid->mline;
-	ft.uline=tmaid->uline;
-	ft.vline=tmaid->vline;
-	ft.font_name=g_strdup(tmaid->font_name);
-	g_memmove(ft.color,tmaid->color,sizeof(GdkColor)*12);
 	ft.text=ft.ext=NULL;
+	property_copy (&ft, &tmaid->ft);
 	if (property_dialog(&ft)) {
 		if (ft.ft_id<0) {
 			/* ̵°ΤȤˤϤΥɥѹ */
 			property_change(tmaid,&ft);
 		} else {
 			/* Ʊե륿פ򤹤٤ѹ */
-			tmaid->ft_id=ft.ft_id;
+			tmaid->ft.ft_id=ft.ft_id;
 			for (i=0;i<ftnum;i++)
 				if (ftype[i].ft_id==ft.ft_id) {
-					ftype[i].margin=ft.margin;
-					ftype[i].tab=ft.tab;
-					ftype[i].autoindent=ft.autoindent;
-					ftype[i].code=ft.code;
-					ftype[i].crlf=ft.crlf;
-					ftype[i].eof=ft.eof;
-					ftype[i].limit=ft.limit;
-					ftype[i].overwrite=ft.overwrite;
-					ftype[i].space=ft.space;
-					ftype[i].syscol=ft.syscol;
-					ftype[i].gline=ft.gline;
-					ftype[i].mline=ft.mline;
-					ftype[i].uline=ft.uline;
-					ftype[i].vline=ft.vline;
-					g_free(ftype[i].font_name);
-					ftype[i].font_name=g_strdup(ft.font_name);
-					g_memmove(ftype[i].color,ft.color,sizeof(GdkColor)*12);
+					property_copy (ftype+i, &ft);
 					break;
 				}
 			glist=gtk_container_children(GTK_CONTAINER(notebook));
 			for (i=g_list_length(glist)-1;i>=0;i--) {
 				tmaid=gtk_object_get_user_data(
 										GTK_OBJECT(g_list_nth_data(glist,i)));
-				if (tmaid->ft_id==ft.ft_id)
+				if (tmaid->ft.ft_id==ft.ft_id)
 					property_change(tmaid,&ft);
 			}
 			g_list_free(glist);
