@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -49,7 +49,7 @@ static void conf_dialog_clicked(GtkWidget *widget,GtkWidget *dialog)
 {
 	gint i;
 	GList *glist;
-	GtkWidget *sub_menu;
+	GtkWidget *menu_shell;
 
 	history=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin0));
 	newfile=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check0));
@@ -66,10 +66,12 @@ static void conf_dialog_clicked(GtkWidget *widget,GtkWidget *dialog)
 		n_pos=GTK_POS_BOTTOM;
 	gtk_widget_destroy(dialog);
 	/*  */
-	sub_menu=gtk_item_factory_get_widget(item_factory_menu,"<main>/File");
-	glist=gtk_container_children(GTK_CONTAINER(sub_menu));
+	menu_shell = gtk_item_factory_get_widget (item_factory_menu,
+																"<main>/File");
+	glist = gtk_container_children (GTK_CONTAINER (menu_shell));
 	for (i=g_list_length(glist)-3;i>history-(history==0)+MENUFILE-2;i--)
-		gtk_container_remove(GTK_CONTAINER(sub_menu),g_list_nth_data(glist,i));
+		gtk_container_remove (GTK_CONTAINER (menu_shell),
+												g_list_nth_data (glist, i));
 	g_list_free(glist);
 	/* ΡȤΰ */
 	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(notebook),n_pos);
