@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -58,7 +58,7 @@ gint edit_get_width(TmaidWindow *tmaid,const gint y)
 	if (p->margin)
 		while (data_pos<p->length-1)
 			if (p->text[data_pos]=='\t') {
-				width=(width/tmaid->tab+1)*tmaid->tab;
+				width=(width/tmaid->ft.tab+1)*tmaid->ft.tab;
 				data_pos++;
 			} else if (data_pos+charset_length(p->text[data_pos])<=p->length) {
 				if (data_pos+charset_length(p->text[data_pos])==p->length)
@@ -73,7 +73,7 @@ gint edit_get_width(TmaidWindow *tmaid,const gint y)
 	else
 		while (data_pos<p->length)
 			if (p->text[data_pos]=='\t') {
-				width=(width/tmaid->tab+1)*tmaid->tab;
+				width=(width/tmaid->ft.tab+1)*tmaid->ft.tab;
 				data_pos++;
 			} else if (data_pos+charset_length(p->text[data_pos])<=p->length) {
 				width+=charset_width(tmaid->font,
@@ -102,9 +102,9 @@ gint edit_get_width_max(TmaidWindow *tmaid)
 		data_pos=0;
 		while (data_pos<p->length)
 			if (p->text[data_pos]=='\t') {
-				width=(width/tmaid->tab+1)*tmaid->tab;
+				width=(width/tmaid->ft.tab+1)*tmaid->ft.tab;
 				data_pos++;
-			} else if (data_pos+charset_length(p->text[data_pos])>p->length) {
+			} else if (data_pos+charset_length(p->text[data_pos])<=p->length) {
 				width+=charset_width(tmaid->font,
 										p->text+data_pos,tmaid->font_width);
 				data_pos+=charset_length(p->text[data_pos]);
@@ -135,10 +135,10 @@ gint edit_get_align_pos(TmaidWindow *tmaid,const gint x,const gint y,
 	if (p->margin)
 		while (screen_pos<x && data_pos<p->length-1)
 			if (p->text[data_pos]=='\t') {
-				if (x<(screen_pos/tmaid->tab+1)*tmaid->tab)
-					return align?(screen_pos/tmaid->tab+1)*tmaid->tab
+				if (x<(screen_pos/tmaid->ft.tab+1)*tmaid->ft.tab)
+					return align?(screen_pos/tmaid->ft.tab+1)*tmaid->ft.tab
 																:screen_pos;
-				screen_pos=(screen_pos/tmaid->tab+1)*tmaid->tab;
+				screen_pos=(screen_pos/tmaid->ft.tab+1)*tmaid->ft.tab;
 				data_pos++;
 			} else if (data_pos+charset_length(p->text[data_pos])>p->length) {
 				screen_pos++;
@@ -157,10 +157,10 @@ gint edit_get_align_pos(TmaidWindow *tmaid,const gint x,const gint y,
 	else
 		while (screen_pos<x && data_pos<p->length)
 			if (p->text[data_pos]=='\t') {
-				if (x<(screen_pos/tmaid->tab+1)*tmaid->tab)
-					return align?(screen_pos/tmaid->tab+1)*tmaid->tab
+				if (x<(screen_pos/tmaid->ft.tab+1)*tmaid->ft.tab)
+					return align?(screen_pos/tmaid->ft.tab+1)*tmaid->ft.tab
 																:screen_pos;
-				screen_pos=(screen_pos/tmaid->tab+1)*tmaid->tab;
+				screen_pos=(screen_pos/tmaid->ft.tab+1)*tmaid->ft.tab;
 				data_pos++;
 			} else if (data_pos+charset_length(p->text[data_pos])>p->length) {
 				screen_pos++;
@@ -193,7 +193,7 @@ gint edit_get_data_pos(TmaidWindow *tmaid,const gint x,const gint y,
 	p=edit_get_line_buf(&tmaid->start,&tmaid->off,y);
 	while (screen_pos<x && data_pos<p->length)
 		if (p->text[data_pos]=='\t') {
-			screen_pos=(screen_pos/tmaid->tab+1)*tmaid->tab;
+			screen_pos=(screen_pos/tmaid->ft.tab+1)*tmaid->ft.tab;
 			if (x<screen_pos)
 				return align?data_pos+1:data_pos;
 			data_pos++;
@@ -225,7 +225,7 @@ gint edit_get_screen_pos(TmaidWindow *tmaid,const gint x,const gint y)
 	p=edit_get_line_buf(&tmaid->start,&tmaid->off,y);
 	while (data_pos<x)
 		if (p->text[data_pos]=='\t') {
-			screen_pos=(screen_pos/tmaid->tab+1)*tmaid->tab;
+			screen_pos=(screen_pos/tmaid->ft.tab+1)*tmaid->ft.tab;
 			data_pos++;
 		} else if (data_pos+charset_length(p->text[data_pos])<=x) {
 			screen_pos+=charset_width(tmaid->font,
@@ -429,12 +429,12 @@ gint edit_put_mem(TmaidWindow *tmaid,GdkPoint *put,GdkPoint *new,
 		temp_leng=0;
 		temp=NULL;
 	}
-	if (tmaid->limit) {
+	if (tmaid->ft.limit) {
 		/* ޡޤ֤ */
 		screen_pos=0;
 		for (data_pos=0;data_pos<p->length;data_pos++)
 			if (p->text[data_pos]=='\t')
-				screen_pos=(screen_pos/tmaid->tab+1)*tmaid->tab;
+				screen_pos=(screen_pos/tmaid->ft.tab+1)*tmaid->ft.tab;
 			else if (data_pos+charset_length(text[data_pos])<=length)
 				screen_pos+=charset_width(tmaid->font,
 										p->text+data_pos,tmaid->font_width);
@@ -444,19 +444,19 @@ gint edit_put_mem(TmaidWindow *tmaid,GdkPoint *put,GdkPoint *new,
 			data_pos=i;
 			while (data_pos<length && text[data_pos]!='\n')
 				if (text[data_pos]=='\t') {
-					screen_pos=(screen_pos/tmaid->tab+1)*tmaid->tab;
-					if (tmaid->margin<screen_pos)
+					screen_pos=(screen_pos/tmaid->ft.tab+1)*tmaid->ft.tab;
+					if (tmaid->ft.margin<screen_pos)
 						break;
 					data_pos++;
 				} else if (data_pos+charset_length(text[data_pos])<=length) {
 					screen_pos+=charset_width(tmaid->font,
 										p->text+data_pos,tmaid->font_width);
-					if (tmaid->margin<screen_pos)
+					if (tmaid->ft.margin<screen_pos)
 						break;
 					data_pos+=charset_length(text[data_pos]);
 				} else {
 					screen_pos++;
-					if (tmaid->margin<screen_pos)
+					if (tmaid->ft.margin<screen_pos)
 						break;
 					data_pos++;
 				}
@@ -524,7 +524,7 @@ gint edit_put_mem(TmaidWindow *tmaid,GdkPoint *put,GdkPoint *new,
 		data_pos=0;
 		while (data_pos<p->length)
 			if (p->text[data_pos]=='\t') {
-				new->x=(new->x/tmaid->tab+1)*tmaid->tab;
+				new->x=(new->x/tmaid->ft.tab+1)*tmaid->ft.tab;
 				data_pos++;
 			} else if (data_pos+charset_length(p->text[data_pos])<=p->length) {
 				new->x+=charset_width(tmaid->font,
@@ -535,8 +535,8 @@ gint edit_put_mem(TmaidWindow *tmaid,GdkPoint *put,GdkPoint *new,
 				data_pos++;
 			}
 		new->y=put->y+insert;
-		if (tmaid->limit && p->margin && (tmaid->margin<=new->x
-				|| (temp!=NULL && tmaid->margin<=new->x
+		if (tmaid->ft.limit && p->margin && (tmaid->ft.margin<=new->x
+				|| (temp!=NULL && tmaid->ft.margin<=new->x
 						+charset_width(tmaid->font,temp,tmaid->font_width)))) {
 			new->x=0;
 			new->y++;
@@ -549,29 +549,29 @@ gint edit_put_mem(TmaidWindow *tmaid,GdkPoint *put,GdkPoint *new,
 		p->length+=temp_leng;
 		g_free(temp);
 	}
-	if (tmaid->limit)
+	if (tmaid->ft.limit)
 		/* ޡޤ֤ */
 		while (p!=NULL) {
 			data_pos=screen_pos=0;
 			while (data_pos<p->length)
 				if (p->text[data_pos]=='\t') {
-					screen_pos=(screen_pos/tmaid->tab+1)*tmaid->tab;
-					if (tmaid->margin<screen_pos)
+					screen_pos=(screen_pos/tmaid->ft.tab+1)*tmaid->ft.tab;
+					if (tmaid->ft.margin<screen_pos)
 						break;
 					data_pos++;
 				} else if (data_pos+charset_length(text[data_pos])<=length) {
 					screen_pos+=charset_width(tmaid->font,
 											text+data_pos,tmaid->font_width);
-					if (tmaid->margin<screen_pos)
+					if (tmaid->ft.margin<screen_pos)
 						break;
 					data_pos+=charset_length(text[data_pos]);
 				} else {
 					screen_pos++;
-					if (tmaid->margin<screen_pos)
+					if (tmaid->ft.margin<screen_pos)
 						break;
 					data_pos++;
 				}
-			if (tmaid->margin<screen_pos) {
+			if (tmaid->ft.margin<screen_pos) {
 				/* ޡĶƤȤԤ */
 				q=g_malloc(sizeof(LineBuffer));
 				q->length=p->length-data_pos;
@@ -588,7 +588,7 @@ gint edit_put_mem(TmaidWindow *tmaid,GdkPoint *put,GdkPoint *new,
 				p->text=g_realloc(p->text,p->length*sizeof(gchar));
 				p=q;
 				insert++;
-			} else if (screen_pos<tmaid->margin
+			} else if (screen_pos<tmaid->ft.margin
 											&& p->margin && p->next!=NULL) {
 				/* ޡ򲼲굼ԤΤȤιԤȤ碌 */
 				data_pos=p->length;
@@ -665,7 +665,7 @@ gint edit_del_sel_mem(TmaidWindow *tmaid,GdkPoint *start_p,GdkPoint *end_p)
 			data_pos=screen_pos=0;
 			while (data_pos<q->length)
 				if (q->text[data_pos]=='\t') {
-					screen_pos=(screen_pos/tmaid->tab+1)*tmaid->tab;
+					screen_pos=(screen_pos/tmaid->ft.tab+1)*tmaid->ft.tab;
 					data_pos++;
 				} else if (data_pos+charset_length(q->text[data_pos])
 																<=q->length) {
@@ -677,7 +677,7 @@ gint edit_del_sel_mem(TmaidWindow *tmaid,GdkPoint *start_p,GdkPoint *end_p)
 					data_pos++;
 				}
 			if (p->text[0]=='\t')
-				screen_pos=(screen_pos/tmaid->tab+1)*tmaid->tab;
+				screen_pos=(screen_pos/tmaid->ft.tab+1)*tmaid->ft.tab;
 			else if (charset_length(p->text[0])<=p->length)
 				screen_pos+=charset_width(tmaid->font,
 													p->text,tmaid->font_width);
@@ -686,7 +686,7 @@ gint edit_del_sel_mem(TmaidWindow *tmaid,GdkPoint *start_p,GdkPoint *end_p)
 		} else {
 			screen_pos=0;
 		}
-		if (p->length<=0 || screen_pos<=tmaid->margin) {
+		if (p->length<=0 || screen_pos<=tmaid->ft.margin) {
 			/* ޡ򲼲굼ԤΤȤιԤȤ碌 */
 			data_pos=q->length;
 			if (p->next!=NULL)
@@ -710,29 +710,29 @@ gint edit_del_sel_mem(TmaidWindow *tmaid,GdkPoint *start_p,GdkPoint *end_p)
 			}
 		}
 	}
-	if (tmaid->limit)/* ޡޤ֤ */
+	if (tmaid->ft.limit)/* ޡޤ֤ */
 		while (p!=NULL) {
 			data_pos=screen_pos=0;
 			while (data_pos<p->length)
 				if (p->text[data_pos]=='\t') {
-					screen_pos=(screen_pos/tmaid->tab+1)*tmaid->tab;
-					if (tmaid->margin<screen_pos)
+					screen_pos=(screen_pos/tmaid->ft.tab+1)*tmaid->ft.tab;
+					if (tmaid->ft.margin<screen_pos)
 						break;
 					data_pos++;
 				} else if (data_pos+charset_length(p->text[data_pos])
 																<=p->length) {
 					screen_pos+=charset_width(tmaid->font,
 										p->text+data_pos,tmaid->font_width);
-					if (tmaid->margin<screen_pos)
+					if (tmaid->ft.margin<screen_pos)
 						break;
 					data_pos+=charset_length(p->text[data_pos]);
 				} else {
 					screen_pos++;
-					if (tmaid->margin<screen_pos)
+					if (tmaid->ft.margin<screen_pos)
 						break;
 					data_pos++;
 				}
-			if (tmaid->margin<screen_pos) {
+			if (tmaid->ft.margin<screen_pos) {
 				/* ޡĶƤȤԤ */
 				q=g_malloc(sizeof(LineBuffer));
 				q->length=p->length-data_pos;
@@ -749,7 +749,7 @@ gint edit_del_sel_mem(TmaidWindow *tmaid,GdkPoint *start_p,GdkPoint *end_p)
 				p->text=g_realloc(p->text,p->length*sizeof(gchar));
 				p=q;
 				result--;
-			} else if (screen_pos<tmaid->margin
+			} else if (screen_pos<tmaid->ft.margin
 											&& p->margin && p->next!=NULL) {
 				/* ޡ򲼲굼ԤΤȤιԤȤ碌 */
 				data_pos=p->length;
