@@ -19,6 +19,7 @@
 #include "abort.h"
 #include "charset.h"
 #include "file.h"
+#include "prop.h"
 #include "signal.h"
 #include "misc/misc.h"
 
@@ -35,29 +36,30 @@ void file_set_history(const gchar *file)
 	gchar *label;
 	gint i,count;
 	GList *glist;
-	GtkWidget *sub_menu,*menu_item;
+	GtkWidget *menu_shell, *menu_item;
 
-	sub_menu=gtk_item_factory_get_widget(item_factory_menu,"<main>/File");
-	glist=gtk_container_children(GTK_CONTAINER(sub_menu));
+	menu_shell = gtk_item_factory_get_widget (item_factory_menu,
+																"<main>/File");
+	glist = gtk_container_children (GTK_CONTAINER (menu_shell));
 	count=g_list_length(glist);
 	for (i=0;i<count-MENUFILE-1;i++) {
 		menu_item=g_list_nth_data(glist,i+MENUFILE-1);
 		label=gtk_object_get_user_data(GTK_OBJECT(menu_item));
 		if (g_strcmp(label,file)==0) {
-			gtk_container_remove(GTK_CONTAINER(sub_menu),menu_item);
+			gtk_container_remove (GTK_CONTAINER (menu_shell), menu_item);
 			break;
 		}
 	}
 	g_list_free(glist);
 	if (i>=history) {
-		glist=gtk_container_children(GTK_CONTAINER(sub_menu));
-		gtk_container_remove(GTK_CONTAINER(sub_menu),
-								g_list_nth_data(glist,MENUFILE+history+1-3));
+		glist = gtk_container_children (GTK_CONTAINER (menu_shell));
+		gtk_container_remove (GTK_CONTAINER (menu_shell),
+						g_list_nth_data (glist, MENUFILE + history + 1 - 3));
 		g_list_free(glist);
 	}
 	if (count<=MENUFILE) {
 		menu_item=gtk_menu_item_new();
-		gtk_menu_insert(GTK_MENU(sub_menu),menu_item,MENUFILE-2);
+		gtk_menu_insert (GTK_MENU (menu_shell), menu_item, MENUFILE - 2);
 		gtk_widget_show(menu_item);
 	}
 	label=g_strdup(file);
@@ -67,7 +69,7 @@ void file_set_history(const gchar *file)
 	gtk_signal_connect(GTK_OBJECT(menu_item),"destroy",
 						GTK_SIGNAL_FUNC(signal_destroy_menu_history),label);
 	gtk_object_set_user_data(GTK_OBJECT(menu_item),label);
-	gtk_menu_insert(GTK_MENU(sub_menu),menu_item,MENUFILE-1);
+	gtk_menu_insert (GTK_MENU (menu_shell), menu_item, MENUFILE - 1);
 	gtk_widget_show(menu_item);
 }
 
@@ -239,7 +241,7 @@ TmaidWindow *file_open_edit(const gchar *file)
 	TmaidWindow *tmaid;
 	GdkPixmap *pixmap;
 	GdkBitmap *mask;
-	GtkWidget *table,*sub_menu,*button,*frame,*hbox;
+	GtkWidget *table, *menu_shell, *button, *frame, *hbox;
 	static gint fcount=0;	/* եο */
 	static gchar *xpm[]={
 "8 7 2 1",
@@ -253,31 +255,16 @@ TmaidWindow *file_open_edit(const gchar *file)
 " ..  .. ",
 "..    .."};
 
-	tmaid=g_malloc0 (sizeof (TmaidWindow));
+	tmaid = g_malloc0 (sizeof (TmaidWindow));
 	tmaid->same=-1;
 	tmaid->select.x=-1;
 	if (file==NULL) {
 		/*  */
 		tmaid->file=g_strdup_printf("new%04d",fcount++%1000);
 		tmaid->create=TRUE;
-		i=0;
-		tmaid->ft_id=ftype[0].associate?ftype[0].ft_id:-1;
-		tmaid->margin=ftype[0].margin;
-		tmaid->tab=ftype[0].tab;
-		tmaid->autoindent=ftype[0].autoindent;
-		tmaid->code=ftype[0].code;
-		tmaid->crlf=ftype[0].crlf;
-		tmaid->eof=ftype[0].eof;
-		tmaid->limit=ftype[0].limit;
-		tmaid->overwrite=ftype[0].overwrite;
-		tmaid->space=ftype[0].space;
-		tmaid->syscol=ftype[0].syscol;
-		tmaid->gline=ftype[0].gline;
-		tmaid->mline=ftype[0].mline;
-		tmaid->uline=ftype[0].uline;
-		tmaid->vline=ftype[0].vline;
-		tmaid->font_name=g_strdup(ftype[0].font_name);
-		g_memmove(tmaid->color,ftype[0].color,sizeof(GdkColor)*12);
+		property_copy (&tmaid->ft, ftype);
+		if (!ftype[0].associate)
+			tmaid->ft.ft_id = -1;
 	} else {
 		tmaid->file=misc_get_full_path(file);
 		leng0=g_strlen(tmaid->file);
@@ -296,23 +283,9 @@ TmaidWindow *file_open_edit(const gchar *file)
 		if (i>=ftnum)
 			i=0;
 		tmaid->create=FALSE;
-		tmaid->ft_id=ftype[i].associate?ftype[i].ft_id:-1;
-		tmaid->margin=ftype[i].margin;
-		tmaid->tab=ftype[i].tab;
-		tmaid->autoindent=ftype[i].autoindent;
-		tmaid->code=ftype[i].code;
-		tmaid->crlf=ftype[i].crlf;
-		tmaid->eof=ftype[i].eof;
-		tmaid->limit=ftype[i].limit;
-		tmaid->overwrite=ftype[i].overwrite;
-		tmaid->space=ftype[i].space;
-		tmaid->syscol=ftype[i].syscol;
-		tmaid->gline=ftype[i].gline;
-		tmaid->mline=ftype[i].mline;
-		tmaid->uline=ftype[i].uline;
-		tmaid->vline=ftype[i].vline;
-		tmaid->font_name=g_strdup(ftype[i].font_name);
-		g_memmove(tmaid->color,ftype[i].color,sizeof(GdkColor)*12);
+		property_copy (&tmaid->ft, ftype + i);
+		if (!ftype[i].associate)
+			tmaid->ft.ft_id = -1;
 		file_open_text(tmaid);
 	}
 	if (tmaid->start==NULL) {
@@ -330,11 +303,11 @@ TmaidWindow *file_open_edit(const gchar *file)
 	text=file_add_edit(tmaid->file,&tmaid->same);
 
 	/* ե */
-	if (tmaid->font_name==NULL
-					|| (tmaid->font=gdk_fontset_load(tmaid->font_name))==NULL)
-		tmaid->font=gdk_font_ref(system_font);
-	charset_size(tmaid->font,
-					&tmaid->font_width,&tmaid->font_height,&tmaid->font_ascent);
+	if (tmaid->ft.font_name == NULL
+			|| (tmaid->font = gdk_fontset_load (tmaid->ft.font_name)) == NULL)
+		tmaid->font = gdk_font_ref (system_font);
+	charset_size (tmaid->font,
+				&tmaid->font_width, &tmaid->font_height, &tmaid->font_ascent);
 
 	/* ɽꥢ */
 	tmaid->drawing=gtk_drawing_area_new();
@@ -360,9 +333,10 @@ TmaidWindow *file_open_edit(const gchar *file)
 								GTK_SIGNAL_FUNC(signal_key_press),tmaid);
 	gtk_signal_connect(GTK_OBJECT(tmaid->drawing),"destroy",
 								GTK_SIGNAL_FUNC(signal_destroy_draw),tmaid);
-	gtk_widget_add_events(tmaid->drawing,
-			GDK_FOCUS_CHANGE | GDK_BUTTON_PRESS_MASK | GDK_POINTER_MOTION_MASK
-						| GDK_POINTER_MOTION_HINT_MASK | GDK_BUTTON_RELEASE);
+	gtk_widget_add_events (tmaid->drawing, GDK_POINTER_MOTION_MASK
+							| GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK
+							| GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK
+							| GDK_FOCUS_CHANGE_MASK);
 	GTK_WIDGET_SET_FLAGS(tmaid->drawing,GTK_CAN_FOCUS);
 	/* ץ饤ޥꥻ쥯 */
 	gtk_selection_add_targets(tmaid->drawing,GDK_SELECTION_PRIMARY,targets,
@@ -385,11 +359,12 @@ TmaidWindow *file_open_edit(const gchar *file)
 							GTK_FILL,GTK_EXPAND | GTK_SHRINK | GTK_FILL,0,0);
 	gtk_object_set_user_data(GTK_OBJECT(table),tmaid);
 	/* ˥塼 */
-	sub_menu=gtk_item_factory_get_widget(item_factory_menu,"<main>/Window");
+	menu_shell = gtk_item_factory_get_widget (item_factory_menu,
+															"<main>/Window");
 	tmaid->menu_item=gtk_menu_item_new_with_label(tmaid->file);
 	gtk_signal_connect(GTK_OBJECT(tmaid->menu_item),"activate",
 						GTK_SIGNAL_FUNC(signal_activate_menu_window),table);
-	gtk_menu_append(GTK_MENU(sub_menu),tmaid->menu_item);
+	gtk_menu_append (GTK_MENU (menu_shell), tmaid->menu_item);
 	gtk_widget_show(tmaid->menu_item);
 	/* ܥ */
 	button=gtk_button_new();
@@ -481,7 +456,7 @@ gboolean file_save_text(const gchar *file,TmaidWindow *tmaid)
 		p=p->next;
 	}
 	/* Ǹ^Zդä */
-	if (userbreak && !eof && tmaid->eof && fputc('\x1a',fp)==EOF) {
+	if (userbreak && !eof && tmaid->ft.eof && fputc('\x1a',fp)==EOF) {
 		gtk_grab_remove(dialog);
 		gtk_widget_destroy(dialog);
 		misc_message_box("Text maid",_("Can not write"),0,_("OK"),NULL);
