@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -41,18 +41,22 @@ gint find_num=0;							/* ϿƤ븡ʸ */
 	  type,ʸ°ǼХåե
 	  text,ʸ
 	length,ǡ														*/
-static void make_char_type(gint *type,const gchar *text,const gint length)
+static void
+make_char_type (gint *type, const gchar *text, const gint length)
 {
-	gint i=0,j;
+	gint i = 0, j;
 
-	while (i<length)
-		if (i+charset->length[(gint)(guchar)text[i]]<=length) {
-			for (j=0;j<charset->length[(gint)(guchar)text[i]];j++)
-				type[i+j]=j+1;
-			i+=charset->length[(gint)(guchar)text[i]];
-		} else {
-			type[i++]=1;
-		}
+	while (i < length)
+		if (i + charset_length (text[i]) <= length)
+		  {
+			for (j = 0; j < charset_length (text[i]); j++)
+				type[i + j] = j + 1;
+			i += charset_length (text[i]);
+		  }
+		else
+		  {
+			type[i++] = 1;
+		  }
 }
 
 
@@ -82,8 +86,8 @@ void find_operation(TmaidWindow *tmaid,GdkPoint *start,GdkPoint *end,
 										tmaid->cursor.x,tmaid->cursor.y,FALSE);
 	length0=g_strlen(find);
 	for (i=0;i<256;i++)
-		if (charset->length[i]>max)
-			max=charset->length[i];
+		if (charset_length (i) > max)
+			max = charset_length (i);
 	text=g_malloc((length0+max)*sizeof(gchar));
 	buf=g_malloc((length0+max)*sizeof(gint));
 	if (tmaid->select.x>=0) {
@@ -135,26 +139,23 @@ void find_operation(TmaidWindow *tmaid,GdkPoint *start,GdkPoint *end,
 						&& (data.y<ed.y || (data.y==ed.y && data.x<ed.x))) {
 				if (data.x<q->length) {
 					/* ʸ */
-					if (data.x+charset->length[(gint)(guchar)q->text[data.x]]
-																<=q->length) {
-						g_memmove(text+length1,q->text+data.x,
-								charset->length[(gint)(guchar)q->text[data.x]]
-															*sizeof(gchar));
-						for (i=0;
-							i<charset->length[(gint)(guchar)q->text[data.x]];
-																		i++)
-							buf[i+length1]=charset->length[(gint)(guchar)
-															q->text[data.x]];
-						length1
-							+=charset->length[(gint)(guchar)q->text[data.x]];
-						data.x
-							+=charset->length[(gint)(guchar)q->text[data.x]];
-					} else {
-						text[length1]=q->text[data.x];
-						buf[length1]=1;
+					if (data.x + charset_length (q->text[data.x]) <= q->length)
+					  {
+						g_memmove (text + length1, q->text + data.x,
+							charset_length (q->text[data.x]) * sizeof (gchar));
+						for (i = 0; i < charset_length (q->text[data.x]); i++)
+							buf[i + length1]
+											= charset_length (q->text[data.x]);
+						length1 += charset_length (q->text[data.x]);
+						data.x += charset_length (q->text[data.x]);
+					  }
+					else
+					  {
+						text[length1] = q->text[data.x];
+						buf[length1] = 1;
 						length1++;
 						data.x++;
-					}
+					  }
 				} else {
 					/*  */
 					while (gtk_events_pending())
@@ -395,6 +396,7 @@ gboolean find_dialog(FindString *fd)
 	for (i=0;i<find_num;i++)
 		glist=g_list_append(glist,find_text[i]);
 	combo=gtk_combo_new();
+	gtk_combo_set_value_in_list (GTK_COMBO (combo), FALSE, TRUE);
 	if (find_num>0) {
 		gtk_combo_set_popdown_strings(GTK_COMBO(combo),glist);
 		gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(combo)->entry),find_text[0]);
