@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -66,7 +66,8 @@ static void format_dialog_clicked_new(GtkWidget *widget,GtkWidget *clist)
 	ftype[ftpos+1].ft_id=tcount++;
 	ftype[ftpos+1].text=g_strdup(ftype[ftpos].text);
 	ftype[ftpos+1].ext=g_strdup(ftype[ftpos].ext);
-	ftype[ftpos+1].font_name=g_strdup(ftype[ftpos].font_name);
+	ftype[ftpos + 1].font_name = ftype[ftpos].font_name != NULL
+									? g_strdup (ftype[ftpos].font_name) : NULL;
 	gtk_clist_insert(GTK_CLIST(clist),ftpos+1,&ftype[ftpos+1].text);
 }
 
@@ -124,7 +125,7 @@ static void format_dialog_clicked_edit(GtkWidget *widget,GtkWidget *clist)
 	glist=gtk_container_children(GTK_CONTAINER(notebook));
 	for (i=g_list_length(glist)-1;i>=0;i--) {
 		tmaid=gtk_object_get_user_data(GTK_OBJECT(g_list_nth_data(glist,i)));
-		if (tmaid->ft_id==ftype[ftpos].ft_id)
+		if (tmaid->ft.ft_id==ftype[ftpos].ft_id)
 			property_change(tmaid,&ftype[ftpos]);
 	}
 	g_list_free(glist);
