@@ -451,30 +451,30 @@ void modify_margin(TmaidWindow *tmaid)
 		tmaid->start=tmaid->start->prev;
 	tmaid->off=0;
 	p=tmaid->start;
-	if (tmaid->limit)
+	if (tmaid->ft.limit)
 		/* ޡˤԤ */
 		while (p!=NULL) {
 			data_pos=screen_pos=0;
 			while (data_pos<p->length)
 				if (p->text[data_pos]=='\t') {
-					screen_pos=(screen_pos/tmaid->tab+1)*tmaid->tab;
-					if (tmaid->margin<screen_pos)
+					screen_pos=(screen_pos/tmaid->ft.tab+1)*tmaid->ft.tab;
+					if (tmaid->ft.margin<screen_pos)
 						break;
 					data_pos++;
 				} else if (data_pos+charset_length(p->text[data_pos])
 																<=p->length) {
 					screen_pos+=charset_width(tmaid->font,
 										p->text+data_pos,tmaid->font_width);
-					if (tmaid->margin<screen_pos)
+					if (tmaid->ft.margin<screen_pos)
 						break;
 					data_pos+=charset_length(p->text[data_pos]);
 				} else {
 					screen_pos++;
-					if (tmaid->margin<screen_pos)
+					if (tmaid->ft.margin<screen_pos)
 						break;
 					data_pos++;
 				}
-			if (tmaid->margin<screen_pos) {
+			if (tmaid->ft.margin<screen_pos) {
 				/* ޡĶƤȤԤ */
 				q=g_malloc(sizeof(LineBuffer));
 				q->length=p->length-data_pos;
@@ -491,7 +491,7 @@ void modify_margin(TmaidWindow *tmaid)
 				p->text=g_realloc(p->text,p->length*sizeof(gchar));
 				p=q;
 				tmaid->max++;
-			} else if (screen_pos<tmaid->margin
+			} else if (screen_pos<tmaid->ft.margin
 											&& p->margin && p->next!=NULL) {
 				/* ޡ򲼲굼ԤΤȤιԤȤ碌 */
 				data_pos=p->length;
@@ -625,15 +625,15 @@ void margin_operation(TmaidWindow *tmaid)
 
 	delete_list(&tmaid->undo);
 	delete_list(&tmaid->redo);
-	limit=tmaid->limit;
-	tmaid->limit=TRUE;
+	limit=tmaid->ft.limit;
+	tmaid->ft.limit=TRUE;
 	modify_margin(tmaid);
 	for (p=tmaid->start;p->prev!=NULL;p=p->prev);
 	while (p!=NULL) {
 		p->margin=FALSE;
 		p=p->next;
 	}
-	tmaid->limit=limit;
+	tmaid->ft.limit=limit;
 	tmaid_change_edit (tmaid, TRUE);
 	tmaid->cursor.x=tmaid->cursor.y=tmaid->top.x=tmaid->top.y=0;
 	tmaid->select.x=-1;
@@ -665,7 +665,7 @@ void tab_operation(TmaidWindow *tmaid)
 		data_pos=screen_pos=0;
 		while (data_pos<p->length)
 			if (p->text[data_pos]=='\t') {
-				screen_pos=(screen_pos/tmaid->tab+1)*tmaid->tab;
+				screen_pos=(screen_pos/tmaid->ft.tab+1)*tmaid->ft.tab;
 				data_pos++;
 			} else if (data_pos+charset_length(p->text[data_pos])<=p->length) {
 				screen_pos+=charset_width(tmaid->font,
@@ -681,7 +681,7 @@ void tab_operation(TmaidWindow *tmaid)
 			data_pos=screen_pos=0;
 			while (data_pos<p->length)
 				if (p->text[data_pos]=='\t') {
-					screen_pos=(screen_pos/tmaid->tab+1)*tmaid->tab;
+					screen_pos=(screen_pos/tmaid->ft.tab+1)*tmaid->ft.tab;
 					data_pos++;
 				} else if (data_pos+charset_length(p->text[data_pos])
 																<=p->length) {
