@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -85,8 +85,8 @@ gboolean print_out(TmaidWindow *tmaid,PrintConfig *prncfg)
 	gdk_gc_set_line_attributes(gc,1,
 								GDK_LINE_SOLID,GDK_CAP_BUTT,GDK_JOIN_MITER);
 	for (i=10;i<12;i++)
-		gdk_color_alloc(gdk_colormap_get_system(),
-								(tmaid->syscol?system_color:tmaid->color)+i);
+		gdk_color_alloc (gdk_colormap_get_system(),
+					(tmaid->ft.syscol ? system_color : tmaid->ft.color) + i);
 	p=edit_get_line_buf(&tmaid->start,&tmaid->off,start.y);
 	end_pos=edit_get_data_pos(tmaid,end.x,end.y,FALSE);
 	line=start.y;
@@ -98,9 +98,11 @@ gboolean print_out(TmaidWindow *tmaid,PrintConfig *prncfg)
 	while (line<=end.y) {
 		/* ڡ */
 		/* ط */
-		gdk_gc_set_foreground(gc,(tmaid->syscol?system_color:tmaid->color)+11);
+		gdk_gc_set_foreground (gc, (tmaid->ft.syscol
+									? system_color : tmaid->ft.color) + 11);
 		gdk_draw_rectangle(pixmap,gc,TRUE,0,0,sx,sy);
-		gdk_gc_set_foreground(gc,(tmaid->syscol?system_color:tmaid->color)+10);
+		gdk_gc_set_foreground (gc, (tmaid->ft.syscol
+									? system_color : tmaid->ft.color) + 10);
 		x=y=0;
 		while (y<=sy-tmaid->font_height && line<=end.y) {
 			while (gtk_events_pending())
@@ -115,7 +117,7 @@ gboolean print_out(TmaidWindow *tmaid,PrintConfig *prncfg)
 						break;
 				}
 				if (p->text[data_pos]=='\t')
-					width=(x/tmaid->font_width/tmaid->tab+1)*tmaid->tab
+					width=(x/tmaid->font_width/tmaid->ft.tab+1)*tmaid->ft.tab
 														*tmaid->font_width-x;
 				else if (data_pos+charset_length(p->text[data_pos])<=p->length)
 					width=tmaid->font_width*charset_width(tmaid->font,
@@ -145,51 +147,54 @@ gboolean print_out(TmaidWindow *tmaid,PrintConfig *prncfg)
 			x=0;
 			y+=tmaid->font_height;
 		}
-		fprintf(fp,
+		fprintf (fp,
+			"gsave\n"
 			"%d %d translate\n"
 			"%d %d scale\n"
 			"%d %d 8 [%d 0 0 %d 0 0]\n"
-			"{currentfile 32 string readhexstring pop}\n"
+			"{currentfile %d string readhexstring pop}\n"
 			"image\n",
-			prncfg->left,prncfg->bottom,
-			prncfg->width-prncfg->left-prncfg->right,
-			prncfg->height-prncfg->top-prncfg->bottom,
-			sx,sy,sx,sy);
+			prncfg->left, prncfg->bottom,
+			prncfg->width - prncfg->left - prncfg->right,
+			prncfg->height - prncfg->top - prncfg->bottom,
+			sx, sy, sx, sy, sx);
 		gdk_pixbuf_get_from_drawable(pixbuf,pixmap,gdk_colormap_get_system(),
 																0,0,0,0,sx,sy);
 		channels=gdk_pixbuf_get_n_channels(pixbuf);
 		rowstride=gdk_pixbuf_get_rowstride(pixbuf);
 		c=gdk_pixbuf_get_pixels(pixbuf);
 		i=0;
-		switch (channels) {
+		switch (channels)
+		  {
 			case 1:
-				for (y=sy-1;y>=0;y--)
-					for (x=0;x<sx;x++) {
-						fprintf(fp,"%02x",c[x*channels+y*rowstride]);
-						if (++i%32==0)
-							fputc('\n',fp);
-					}
+				for (y = sy - 1; y >= 0; y--)
+				  {
+					for (x = 0; x < sx; x++)
+						fprintf (fp, "%02x", c[x * channels + y * rowstride]);
+					fputc ('\n', fp);
+				  }
 				break;
 			case 3:
 			case 4:
-				for (y=sy-1;y>=0;y--)
-					for (x=0;x<sx;x++) {
-						fprintf(fp,"%02x",(c[x*channels+y*rowstride]*77
-										+c[x*channels+y*rowstride+1]*150
-										+c[x*channels+y*rowstride+2]*29)/256);
-						if (++i%32==0)
-							fputc('\n',fp);
-					}
+				for (y = sy - 1;y >= 0; y--)
+				  {
+					for (x = 0; x < sx; x++)
+						fprintf (fp, "%02x",
+							(c[x * channels + y * rowstride] * 77
+							+c[x * channels + y * rowstride + 1] * 150
+							+c[x * channels + y * rowstride + 2] * 29) / 256);
+					fputc('\n',fp);
+				  }
 				break;
 			default:
-				for (y=0;y<sy;y++)
-					for (x=0;x<sx;x++) {
-						fputs("ff",fp);
-						if (++i%32==0)
-							fputc('\n',fp);
-					}
-		}
-		fputs("showpage\n",fp);
+				for (y = 0; y < sy; y++)
+				  {
+					for (x = 0; x < sx; x++)
+						fputs ("ff", fp);
+					fputc ('\n', fp);
+				  }
+		  }
+		fputs("grestore\nshowpage\n",fp);
 		if (!userbreak)
 			goto loop;
 	}
