@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,6 +31,42 @@
 * ץѥƥؿ                                                            *
 *                                                                             *
 ******************************************************************************/
+/*	ץѥƥ򥳥ԡ
+	ft_dst,ԡ
+	ft_src,ԡ															*/
+void
+property_copy (FileType *ft_dst, FileType *ft_src)
+{
+	ft_dst->ft_id = ft_src->ft_id;
+	ft_dst->margin = ft_src->margin;
+	ft_dst->tab = ft_src->tab;
+	ft_dst->autoindent = ft_src->autoindent;
+	ft_dst->code = ft_src->code;
+	ft_dst->eof = ft_src->eof;
+	ft_dst->limit = ft_src->limit;
+	ft_dst->overwrite = ft_src->overwrite;
+	ft_dst->space = ft_src->space;
+	ft_dst->syscol = ft_src->syscol;
+	ft_dst->gline = ft_src->gline;
+	ft_dst->mline = ft_src->mline;
+	ft_dst->nline = ft_src->nline;
+	ft_dst->uline = ft_src->uline;
+	ft_dst->vline = ft_src->vline;
+	g_free (ft_dst->font_name);
+	ft_dst->font_name = ft_src->font_name != NULL
+										? g_strdup (ft_src->font_name) : NULL;
+	if (ft_dst->text != NULL && ft_dst->ext != NULL
+								&& ft_src->text != NULL && ft_src->ext != NULL)
+	  {
+		g_free (ft_dst->text);
+		g_free (ft_dst->ext);
+		ft_dst->text = g_strdup (ft_src->text);
+		ft_dst->ext = g_strdup (ft_src->ext);
+	  }
+	g_memmove (ft_dst->color, ft_src->color, sizeof (GdkColor) * 12);
+}
+
+
 /*	ץѥƥѹ
 	tmaid,TXTɥ
 	   ft,ե륿													*/
@@ -39,38 +75,22 @@ void property_change(TmaidWindow *tmaid,FileType *ft)
 	gboolean modify;
 	gint max,sx,sy;
 
-	if (tmaid->limit!=ft->limit || tmaid->tab!=ft->tab
-							|| (tmaid->code && tmaid->margin!=ft->margin)) {
+	if (tmaid->ft.limit != ft->limit || tmaid->ft.tab != ft->tab
+						|| (tmaid->ft.code && tmaid->ft.margin != ft->margin))
+	  {
 		/* ޤ֤ѹֿѹ */
-		delete_list(&tmaid->undo);
-		delete_list(&tmaid->redo);
-	}
-	modify=tmaid->limit!=ft->limit || (tmaid->limit
-						&& (tmaid->tab!=ft->tab || tmaid->margin!=ft->margin
-							|| g_strcmp(tmaid->font_name,ft->font_name)!=0));
-	tmaid->ft_id=ft->ft_id;
-	tmaid->margin=ft->margin;
-	tmaid->tab=ft->tab;
-	tmaid->autoindent=ft->autoindent;
-	tmaid->code=ft->code;
-	tmaid->crlf=ft->crlf;
-	tmaid->eof=ft->eof;
-	tmaid->limit=ft->limit;
-	tmaid->overwrite=ft->overwrite;
-	tmaid->space=ft->space;
-	tmaid->syscol=ft->syscol;
-	tmaid->gline=ft->gline;
-	tmaid->mline=ft->mline;
-	tmaid->uline=ft->uline;
-	tmaid->vline=ft->vline;
-	g_free(tmaid->font_name);
-	tmaid->font_name=g_strdup(ft->font_name);
-	g_memmove(tmaid->color,ft->color,sizeof(GdkColor)*12);
+		delete_list (&tmaid->undo);
+		delete_list (&tmaid->redo);
+	  }
+	modify = tmaid->ft.limit != ft->limit || (tmaid->ft.limit
+				&& (tmaid->ft.tab != ft->tab || tmaid->ft.margin != ft->margin
+					|| g_strcmp (tmaid->ft.font_name, ft->font_name) != 0));
+	property_copy (&tmaid->ft, ft);
 	tmaid->select.x=-1;
 	/* ե */
-	if (tmaid->font_name!=NULL) {
+	if (tmaid->ft.font_name!=NULL) {
 		gdk_font_unref(tmaid->font);
-		if ((tmaid->font=gdk_fontset_load(tmaid->font_name))==NULL)
+		if ((tmaid->font=gdk_fontset_load(tmaid->ft.font_name))==NULL)
 			tmaid->font=gdk_font_ref(system_font);
 		charset_size(tmaid->font,
 				&tmaid->font_width,&tmaid->font_height,&tmaid->font_ascent);
@@ -101,10 +121,10 @@ void property_change(TmaidWindow *tmaid,FileType *ft)
 				&& (gdk_ic_get_style(tmaid->ic)&GDK_IM_PREEDIT_POSITION)!=0) {
 		gdk_ic_get_attr(tmaid->ic,tmaid->ic_attr,GDK_IC_PREEDIT_FONTSET
 					| GDK_IC_PREEDIT_FOREGROUND | GDK_IC_PREEDIT_BACKGROUND);
-		tmaid->ic_attr->preedit_foreground=tmaid->syscol
-											?system_color[0]:tmaid->color[0];
-		tmaid->ic_attr->preedit_background=tmaid->syscol
-											?system_color[1]:tmaid->color[1];
+		tmaid->ic_attr->preedit_foreground = tmaid->ft.syscol
+										? system_color[0] : tmaid->ft.color[0];
+		tmaid->ic_attr->preedit_background = tmaid->ft.syscol
+										? system_color[1] : tmaid->ft.color[1];
 		tmaid->ic_attr->preedit_fontset=tmaid->font;
 		gdk_ic_set_attr(tmaid->ic,tmaid->ic_attr,GDK_IC_PREEDIT_FONTSET
 					| GDK_IC_PREEDIT_FOREGROUND | GDK_IC_PREEDIT_BACKGROUND);
@@ -296,7 +316,7 @@ static void property_dialog_clicked_ftype(GtkWidget *widget,gpointer user_data)
 			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check1),
 														ftype[pos].space);
 			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check2),
-														ftype[pos].crlf);
+														ftype[pos].nline);
 			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check3),
 														ftype[pos].mline);
 			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check4),
@@ -347,7 +367,7 @@ static void property_dialog_clicked_ok(GtkWidget *widget,FileType *ft)
 	ft->tab=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin1));
 	ft->gline=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check0));
 	ft->space=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check1));
-	ft->crlf=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check2));
+	ft->nline=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check2));
 	ft->mline=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check3));
 	ft->limit=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check4));
 	ft->code=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check5));
@@ -422,8 +442,8 @@ gboolean property_dialog(FileType *ft)
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button1)->child),_("_Font"));
 	gtk_widget_add_accelerator(button1,"clicked",accel,key,GDK_MOD1_MASK,0);
 	if (button2!=NULL) {
-		key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button2)->child),
-													_("Associated File Type"));
+		key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (button2)->child),
+												_("_Associated File Type"));
 		gtk_widget_add_accelerator(button2,"clicked",accel,key,
 															GDK_MOD1_MASK,0);
 	}
@@ -493,7 +513,7 @@ gboolean property_dialog(FileType *ft)
 	gtk_widget_add_accelerator(check11,"clicked",accel,key,GDK_MOD1_MASK,0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check0),ft->gline);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check1),ft->space);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check2),ft->crlf);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check2),ft->nline);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check3),ft->mline);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check4),ft->limit);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check5),ft->code);
@@ -550,10 +570,10 @@ gboolean property_dialog(FileType *ft)
 											property_dialog_ok_sensitive,NULL);
 		gtk_signal_connect(GTK_OBJECT(entry1),"changed",
 											property_dialog_ok_sensitive,NULL);
-		gtk_signal_connect(GTK_OBJECT(entry0),"activate",
-												property_dialog_clicked_ok,ft);
-		gtk_signal_connect(GTK_OBJECT(entry1),"activate",
-												property_dialog_clicked_ok,ft);
+		gtk_signal_connect (GTK_OBJECT (entry0), "activate",
+												property_dialog_activate, ft);
+		gtk_signal_connect (GTK_OBJECT (entry1), "activate",
+												property_dialog_activate, ft);
 	} else {
 		if (ft->ft_id>=0) {
 			/* ե륿פ */
