@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,6 +23,13 @@
 #include "tmaid.h"
 
 
+/*	vpeBRs[
+	ft_dst,Rs[
+	ft_src,Rs[															*/
+void
+property_copy (FileType *ft_dst, FileType *ft_src);
+
+
 /*	vpeBύX
 	tmaid,TXTEChE
 	   ft,t@C^Cv													*/
