@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
 */
 #include <gdk/gdkkeysyms.h>
 #include "repinfo.h"
+#include "replace.h"
 
 
 /******************************************************************************
@@ -25,15 +26,12 @@
 * ִ                                                        *
 *                                                                             *
 ******************************************************************************/
-static gint repinfo_clicked_button;
-static GtkWidget *dialog;
-
-
 /* ܥ󤬲줿 */
-static void repinfo_dialog_clicked(GtkWidget *widget,gint button)
+static void repinfo_dialog_clicked(GtkWidget *widget,GtkWidget *dialog)
 {
+	*(gint *)gtk_object_get_user_data(GTK_OBJECT(dialog))
+						=(gint)gtk_object_get_user_data(GTK_OBJECT(widget));
 	gtk_widget_destroy(dialog);
-	repinfo_clicked_button=button;
 }
 
 
@@ -47,12 +45,13 @@ static gboolean repinfo_dialog_key_press(GtkWidget *widget,GdkEventKey *event,
 }
 
 
-gint repinfo_dialog(REPINFO *ri)
+gint repinfo_dialog(ReplaceInfo *ri)
 {
 	gchar *text;
+	gint result=REPLACE_CANCEL;
 	guint key;
 	GtkAccelGroup *accel;
-	GtkWidget *button0,*button1,*button2,*button3;
+	GtkWidget *dialog,*button0,*button1,*button2,*button3;
 	GtkWidget *frame0,*frame1,*hbox,*tbox,*vbox;
 
 	/* ᥤ󥦥ɥ */
@@ -61,6 +60,7 @@ gint repinfo_dialog(REPINFO *ri)
 	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
 							GTK_SIGNAL_FUNC(repinfo_dialog_key_press),NULL);
 	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
+	gtk_object_set_user_data(GTK_OBJECT(dialog),&result);
 	/* 졼 */
 	accel=gtk_accel_group_new();
 	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
@@ -77,13 +77,16 @@ gint repinfo_dialog(REPINFO *ri)
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button2)->child),_("_All"));
 	gtk_widget_add_accelerator(button2,"clicked",accel,'A',GDK_MOD1_MASK,0);
 	gtk_signal_connect(GTK_OBJECT(button0),"clicked",
-										repinfo_dialog_clicked,(gpointer)1);
+										repinfo_dialog_clicked,dialog);
 	gtk_signal_connect(GTK_OBJECT(button1),"clicked",
-										repinfo_dialog_clicked,(gpointer)0);
+										repinfo_dialog_clicked,dialog);
 	gtk_signal_connect(GTK_OBJECT(button2),"clicked",
-										repinfo_dialog_clicked,(gpointer)2);
+										repinfo_dialog_clicked,dialog);
 	gtk_signal_connect_object(GTK_OBJECT(button3),"clicked",
 										gtk_widget_destroy,GTK_OBJECT(dialog));
+	gtk_object_set_user_data(GTK_OBJECT(button0),(gpointer)REPLACE_OK);
+	gtk_object_set_user_data(GTK_OBJECT(button1),(gpointer)REPLACE_NEXT);
+	gtk_object_set_user_data(GTK_OBJECT(button2),(gpointer)REPLACE_ALL);
 	GTK_WIDGET_SET_FLAGS(button0,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button1,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button2,GTK_CAN_DEFAULT);
@@ -138,12 +141,11 @@ gint repinfo_dialog(REPINFO *ri)
 
 	/* ɽ */
 	gtk_widget_grab_focus(button1);
-	repinfo_clicked_button=-1;
 
 	gtk_window_set_policy(GTK_WINDOW(dialog),FALSE,TRUE,FALSE);
 	gtk_grab_add(dialog);
 	gtk_widget_show_all(dialog);
 	gtk_main();
 
-	return repinfo_clicked_button;
+	return result;
 }
