@@ -107,10 +107,10 @@ void signal_realize(GtkWidget *widget,TmaidWindow *tmaid)
 			attrmask|=GDK_IC_PREEDIT_COLORMAP;
 			tmaid->ic_attr->preedit_colormap=colormap;
 		}
-		tmaid->ic_attr->preedit_foreground=tmaid->syscol
-											?system_color[0]:tmaid->color[0];
-		tmaid->ic_attr->preedit_background=tmaid->syscol
-											?system_color[1]:tmaid->color[1];
+		tmaid->ic_attr->preedit_foreground = tmaid->ft.syscol
+										? system_color[0] : tmaid->ft.color[0];
+		tmaid->ic_attr->preedit_background = tmaid->ft.syscol
+										? system_color[1] : tmaid->ft.color[1];
 		switch (tmaid->ic_attr->style&GDK_IM_PREEDIT_MASK) {
 			case GDK_IM_PREEDIT_POSITION:
 				if (tmaid->font->type==GDK_FONT_FONTSET) {
@@ -174,7 +174,8 @@ void signal_value_changed_vscroll(GtkAdjustment *adjust,TmaidWindow *tmaid)
 	if (tmaid->top.x>max-sx+1)
 		tmaid->top.x=MAX(max-sx+1,0);
 	move_edit_window(tmaid,&top);
-	if (tmaid->top.x!=top.x)
+	if (tmaid->top.x != top.x
+		|| gtk_range_get_adjustment (GTK_RANGE (tmaid->hscroll))->upper != max)
 		misc_set_scroll_bar(tmaid->hscroll,signal_value_changed_hscroll,tmaid,
 													0,max+1,sx,tmaid->top.x);
 	draw_caret(tmaid,NULL);
@@ -225,8 +226,8 @@ gboolean signal_expose(GtkWidget *widget,
 	gdk_gc_set_line_attributes(gc,1,
 								GDK_LINE_SOLID,GDK_CAP_BUTT,GDK_JOIN_MITER);
 	for (i=0;i<10;i++)
-		gdk_color_alloc(gdk_colormap_get_system(),
-								(tmaid->syscol?system_color:tmaid->color)+i);
+		gdk_color_alloc (gdk_colormap_get_system (),
+					(tmaid->ft.syscol ? system_color : tmaid->ft.color) + i);
 	cursor.x=edit_get_align_pos(tmaid,tmaid->cursor.x,tmaid->cursor.y,FALSE);
 	cursor.y=tmaid->cursor.y;
 	if (tmaid->select.x==-1) {
@@ -244,12 +245,14 @@ gboolean signal_expose(GtkWidget *widget,
 		end=tmaid->select;
 	}
 	/* ط */
-	gdk_gc_set_foreground(gc,(tmaid->syscol?system_color:tmaid->color)+1);
+	gdk_gc_set_foreground (gc, (tmaid->ft.syscol
+										? system_color : tmaid->ft.color) + 1);
 	gdk_draw_rectangle(widget->window,gc,TRUE,event->area.x,event->area.y,
 										event->area.width,event->area.height);
-	if (tmaid->gline) {
+	if (tmaid->ft.gline) {
 		/* å */
-		gdk_gc_set_foreground(gc,(tmaid->syscol?system_color:tmaid->color)+7);
+		gdk_gc_set_foreground (gc, (tmaid->ft.syscol
+										? system_color : tmaid->ft.color) + 7);
 		for (x=tmaid->font_width-1;x<widget->allocation.width;
 														x+=tmaid->font_width)
 			gdk_draw_line(widget->window,gc,x,event->area.y,
@@ -259,18 +262,22 @@ gboolean signal_expose(GtkWidget *widget,
 			gdk_draw_line(widget->window,gc,event->area.x,y,
 										event->area.x+event->area.width,y);
 	}
-	if (tmaid->vline) {
+	if (tmaid->ft.vline) {
 		/*  */
-		gdk_gc_set_foreground(gc,(tmaid->syscol?system_color:tmaid->color)+7);
-		for (x=(tmaid->tab-tmaid->top.x%tmaid->tab)*tmaid->font_width-1;
-					x<widget->allocation.width;x+=tmaid->font_width*tmaid->tab)
+		gdk_gc_set_foreground (gc, (tmaid->ft.syscol
+										? system_color : tmaid->ft.color) + 7);
+		for (x = (tmaid->ft.tab - tmaid->top.x % tmaid->ft.tab)
+													* tmaid->font_width - 1;
+										x < widget->allocation.width;
+										x += tmaid->font_width * tmaid->ft.tab)
 			gdk_draw_line(widget->window,gc,x,event->area.y,
 										x,event->area.y+event->area.height);
 	}
-	if (tmaid->mline) {
+	if (tmaid->ft.mline) {
 		/* ޡ */
-		gdk_gc_set_foreground(gc,(tmaid->syscol?system_color:tmaid->color)+6);
-		x=(tmaid->margin-tmaid->top.x)*tmaid->font_width;
+		gdk_gc_set_foreground (gc, (tmaid->ft.syscol
+										? system_color : tmaid->ft.color) + 6);
+		x=(tmaid->ft.margin-tmaid->top.x)*tmaid->font_width;
 		gdk_draw_line(widget->window,gc,x,event->area.y,
 										x,event->area.y+event->area.height);
 	}
@@ -283,11 +290,12 @@ gboolean signal_expose(GtkWidget *widget,
 		x=-tmaid->top.x*tmaid->font_width;
 		data_pos=0;
 		while (x<=event->area.x+event->area.width && data_pos<p->length) {
-			if (x+MAX(tmaid->tab,2)*tmaid->font_width<event->area.x) {
+			if (x+MAX(tmaid->ft.tab,2)*tmaid->font_width<event->area.x) {
 				/* ¦ɽʤʬ׻ */
 				if (p->text[data_pos]=='\t') {
-					x=(((x/tmaid->font_width+tmaid->top.x)/tmaid->tab+1)
-								*tmaid->tab-tmaid->top.x)*tmaid->font_width;
+					x = (((x / tmaid->font_width + tmaid->top.x)
+														/ tmaid->ft.tab + 1)
+						* tmaid->ft.tab - tmaid->top.x) * tmaid->font_width;
 					data_pos++;
 				} else if (data_pos+charset_length(p->text[data_pos])
 																<=p->length) {
@@ -315,26 +323,27 @@ gboolean signal_expose(GtkWidget *widget,
 								&& tmaid->top.x+x/tmaid->font_width<end.x));
 			if (p->text[data_pos]=='\t') {
 				/*  */
-				width=(((x/tmaid->font_width+tmaid->top.x)/tmaid->tab+1)
-								*tmaid->tab-tmaid->top.x)*tmaid->font_width-x;
+				width = (((x / tmaid->font_width + tmaid->top.x)
+														/ tmaid->ft.tab + 1)
+					* tmaid->ft.tab - tmaid->top.x) * tmaid->font_width - x;
 				if (select) {
 					/*  */
-					gdk_gc_set_foreground(gc,
-								(tmaid->syscol?system_color:tmaid->color)+9);
+					gdk_gc_set_foreground (gc, (tmaid->ft.syscol
+										? system_color : tmaid->ft.color) + 9);
 					gdk_draw_rectangle(widget->window,gc,TRUE,x,y,
 													width,tmaid->font_height);
 				}
-				if (tmaid->uline) {
+				if (tmaid->ft.uline) {
 					/*  */
-					gdk_gc_set_foreground(gc,
-								(tmaid->syscol?system_color:tmaid->color)+5);
+					gdk_gc_set_foreground (gc, (tmaid->ft.syscol
+										? system_color : tmaid->ft.color) + 5);
 					gdk_draw_line(widget->window,gc,x,y+tmaid->font_height-1,
 											x+width,y+tmaid->font_height-1);
 				}
-				if (tmaid->code) {
+				if (tmaid->ft.code) {
 					/* ʸ */
-					gdk_gc_set_foreground(gc,
-								(tmaid->syscol?system_color:tmaid->color)+2);
+					gdk_gc_set_foreground (gc, (tmaid->ft.syscol
+										? system_color : tmaid->ft.color) + 2);
 					gdk_draw_rectangle(widget->window,gc,FALSE,
 								x+tmaid->font_width/6,y+tmaid->font_height/3,
 								tmaid->font_height/3,tmaid->font_height/3);
@@ -346,17 +355,17 @@ gboolean signal_expose(GtkWidget *widget,
 										p->text+data_pos,tmaid->font_width);
 				if (select) {
 					/*  */
-					gdk_gc_set_foreground(gc,
-								(tmaid->syscol?system_color:tmaid->color)+9);
+					gdk_gc_set_foreground (gc, (tmaid->ft.syscol
+										? system_color : tmaid->ft.color) + 9);
 					gdk_draw_rectangle(widget->window,gc,TRUE,x,y,
 													width,tmaid->font_height);
-					gdk_gc_set_foreground(gc,
-								(tmaid->syscol?system_color:tmaid->color)+8);
+					gdk_gc_set_foreground (gc, (tmaid->ft.syscol
+										? system_color : tmaid->ft.color) + 8);
 				} else {
-					gdk_gc_set_foreground(gc,
-									tmaid->syscol?system_color:tmaid->color);
+					gdk_gc_set_foreground (gc, tmaid->ft.syscol
+											? system_color : tmaid->ft.color);
 				}
-				if (tmaid->space && charset->space!=NULL) {
+				if (tmaid->ft.space && charset->space!=NULL) {
 					space=FALSE;/* ѥڡȽ */
 					for (i=0;charset->space[i]!=0;i+=charset->space[i]+1)
 						if (charset_length(p->text[data_pos])
@@ -367,8 +376,8 @@ gboolean signal_expose(GtkWidget *widget,
 				}
 				if (space) {
 					/* ѥڡ */
-					gdk_gc_set_foreground(gc,
-								(tmaid->syscol?system_color:tmaid->color)+3);
+					gdk_gc_set_foreground (gc, (tmaid->ft.syscol
+										? system_color : tmaid->ft.color) + 3);
 					gdk_draw_rectangle(widget->window,gc,TRUE,x+1,y+1,
 												width-1,tmaid->font_height-1);
 				} else {
@@ -383,15 +392,15 @@ gboolean signal_expose(GtkWidget *widget,
 				width=tmaid->font_width;
 				if (select) {
 					/*  */
-					gdk_gc_set_foreground(gc,
-								(tmaid->syscol?system_color:tmaid->color)+9);
+					gdk_gc_set_foreground (gc, (tmaid->ft.syscol
+										? system_color : tmaid->ft.color) + 9);
 					gdk_draw_rectangle(widget->window,gc,TRUE,x,y,
 													width,tmaid->font_height);
-					gdk_gc_set_foreground(gc,
-								(tmaid->syscol?system_color:tmaid->color)+8);
+					gdk_gc_set_foreground (gc, (tmaid->ft.syscol
+										? system_color : tmaid->ft.color) + 8);
 				} else {
-					gdk_gc_set_foreground(gc,
-									tmaid->syscol?system_color:tmaid->color);
+					gdk_gc_set_foreground(gc, tmaid->ft.syscol
+											? system_color : tmaid->ft.color);
 				}
 				gdk_draw_text(widget->window,tmaid->font,gc,
 									x,y+tmaid->font_ascent,p->text+data_pos,1);
@@ -408,17 +417,17 @@ gboolean signal_expose(GtkWidget *widget,
 			}
 			x+=width;
 		}
-		if (data_pos==p->length && tmaid->crlf) {
+		if (data_pos==p->length && tmaid->ft.nline) {
 			if (start.x>=0 && start.y<=tmaid->top.y+y/tmaid->font_height
 								&& tmaid->top.y+y/tmaid->font_height<end.y) {
 				/*  */
-				gdk_gc_set_foreground(gc,
-								(tmaid->syscol?system_color:tmaid->color)+9);
+				gdk_gc_set_foreground (gc, (tmaid->ft.syscol
+										? system_color : tmaid->ft.color) + 9);
 				gdk_draw_rectangle(widget->window,gc,TRUE,x,y,
 										tmaid->font_width,tmaid->font_height);
 			}
-			gdk_gc_set_foreground(gc,
-								(tmaid->syscol?system_color:tmaid->color)+4);
+			gdk_gc_set_foreground (gc, (tmaid->ft.syscol
+										? system_color : tmaid->ft.color) + 4);
 			if (p->next==NULL) {
 				/* եκǸ */
 				gdk_draw_arc(widget->window,gc,TRUE,
@@ -1101,7 +1110,7 @@ gboolean signal_key_press(GtkWidget *widget,
 			LineBuffer *p;
 
 			select=tmaid->select;
-			if (tmaid->autoindent) {
+			if (tmaid->ft.autoindent) {
 				data_pos=edit_get_data_pos(tmaid,
 										tmaid->cursor.x,tmaid->cursor.y,FALSE);
 				p=edit_get_line_buf(&tmaid->start,&tmaid->off,tmaid->cursor.y);
@@ -1359,14 +1368,15 @@ gboolean signal_key_press(GtkWidget *widget,
 void signal_destroy_draw(GtkWidget *widget,TmaidWindow *tmaid)
 {
 	GList *glist;
-	GtkWidget *sub_menu;
+	GtkWidget *menu_shell;
 	LineBuffer *p;
 
 	/* ե̾Ĵ٤ */
 	file_delete_edit(tmaid->file);
 	/* ɥ˥塼 */
-	sub_menu=gtk_item_factory_get_widget(item_factory_menu,"<main>/Window");
-	gtk_container_remove(GTK_CONTAINER(sub_menu),tmaid->menu_item);
+	menu_shell = gtk_item_factory_get_widget (item_factory_menu,
+															"<main>/Window");
+	gtk_container_remove (GTK_CONTAINER (menu_shell), tmaid->menu_item);
 	/* ˥塼 */
 	glist=gtk_container_children(GTK_CONTAINER(notebook));
 	if (g_list_length(glist)<=1) {
@@ -1428,8 +1438,8 @@ void signal_style_set(GtkWidget *widget,GtkStyle *style,gpointer user_data)
 	glist=gtk_container_children(GTK_CONTAINER(notebook));
 	for (i=g_list_length(glist)-1;i>=0;i--) {
 		tmaid=gtk_object_get_user_data(GTK_OBJECT(g_list_nth_data(glist,i)));
-		if (tmaid->syscol || tmaid->font_name==NULL) {
-			if (tmaid->font_name==NULL) {
+		if (tmaid->ft.syscol || tmaid->ft.font_name==NULL) {
+			if (tmaid->ft.font_name==NULL) {
 				/* եѹ */
 				gdk_font_unref(tmaid->font);
 				tmaid->font=gdk_font_ref(system_font);
@@ -1438,12 +1448,14 @@ void signal_style_set(GtkWidget *widget,GtkStyle *style,gpointer user_data)
 				/* С */
 				tmaid->cursor.x=tmaid->cursor.y=tmaid->top.x=tmaid->top.y=0;
 				modify_margin(tmaid);
-				misc_set_scroll_bar(tmaid->hscroll,signal_value_changed_hscroll,
-										tmaid,0,edit_get_width_max(tmaid)+1,
+				misc_set_scroll_bar (tmaid->hscroll,
+									signal_value_changed_hscroll,
+									tmaid, 0, edit_get_width_max (tmaid) + 1,
 					MAX(tmaid->drawing->allocation.width/tmaid->font_width,1),
 																tmaid->top.x);
-				misc_set_scroll_bar(tmaid->vscroll,signal_value_changed_vscroll,
-										tmaid,0,tmaid->max,
+				misc_set_scroll_bar (tmaid->vscroll,
+									signal_value_changed_vscroll,
+									tmaid, 0, tmaid->max,
 					MAX(tmaid->drawing->allocation.height/tmaid->font_height,
 															1),tmaid->top.y);
 			}
@@ -1452,18 +1464,18 @@ void signal_style_set(GtkWidget *widget,GtkStyle *style,gpointer user_data)
 			if (gdk_im_ready() && tmaid->ic!=NULL
 				&& (gdk_ic_get_style(tmaid->ic)&GDK_IM_PREEDIT_POSITION)!=0) {
 				gdk_ic_get_attr(tmaid->ic,tmaid->ic_attr,
-					(tmaid->font_name==NULL?GDK_IC_PREEDIT_FONTSET:0)
-					| (tmaid->syscol?GDK_IC_PREEDIT_FOREGROUND
+					(tmaid->ft.font_name==NULL?GDK_IC_PREEDIT_FONTSET:0)
+					| (tmaid->ft.syscol?GDK_IC_PREEDIT_FOREGROUND
 											| GDK_IC_PREEDIT_BACKGROUND:0));
-				if (tmaid->syscol) {
+				if (tmaid->ft.syscol) {
 					tmaid->ic_attr->preedit_foreground=system_color[0];
 					tmaid->ic_attr->preedit_background=system_color[1];
 				}
-				if (tmaid->font_name==NULL)
+				if (tmaid->ft.font_name==NULL)
 					tmaid->ic_attr->preedit_fontset=tmaid->font;
 				gdk_ic_set_attr(tmaid->ic,tmaid->ic_attr,
-					(tmaid->font_name==NULL?GDK_IC_PREEDIT_FONTSET:0)
-					| (tmaid->syscol?GDK_IC_PREEDIT_FOREGROUND
+					(tmaid->ft.font_name==NULL?GDK_IC_PREEDIT_FONTSET:0)
+					| (tmaid->ft.syscol?GDK_IC_PREEDIT_FOREGROUND
 											| GDK_IC_PREEDIT_BACKGROUND:0));
 			}
 #endif
@@ -1483,7 +1495,7 @@ void signal_activate_menu_window(GtkWidget *widget,GtkWidget *child)
 	gtk_notebook_set_page(GTK_NOTEBOOK(notebook),
 						gtk_notebook_page_num(GTK_NOTEBOOK(notebook),child));
 	gtk_widget_grab_focus(
-			((TmaidWindow *)gtk_object_get_user_data(GTK_OBJECT(child)))->drawing);
+		((TmaidWindow *)gtk_object_get_user_data(GTK_OBJECT(child)))->drawing);
 }
 
 
@@ -1506,7 +1518,8 @@ void signal_destroy_menu_history(GtkWidget *widget,gchar *file)
 ******************************************************************************/
 void signal_clicked(GtkWidget *widget,GtkWidget *child)
 {
-	if (prompt_close((TmaidWindow *)gtk_object_get_user_data(GTK_OBJECT(child))))
+	if (prompt_close ((TmaidWindow *)
+								gtk_object_get_user_data (GTK_OBJECT (child))))
 		gtk_notebook_remove_page(GTK_NOTEBOOK(notebook),
 						gtk_notebook_page_num(GTK_NOTEBOOK(notebook),child));
 }
@@ -1716,11 +1729,12 @@ void signal_destroy_window(GtkWidget *widget,gpointer user_data)
 {
 	gint i;
 	GList *glist;
-	GtkWidget *sub_menu;
+	GtkWidget *menu_shell;
 
 	memset(history_files,0,sizeof(gchar *)*10);
-	sub_menu=gtk_item_factory_get_widget(item_factory_menu,"<main>/File");
-	glist=gtk_container_children(GTK_CONTAINER(sub_menu));
+	menu_shell = gtk_item_factory_get_widget (item_factory_menu,
+																"<main>/File");
+	glist = gtk_container_children (GTK_CONTAINER (menu_shell));
 	for (i=0;i<(gint)g_list_length(glist)-MENUFILE-1;i++)
 		history_files[i]=g_strdup(gtk_object_get_user_data(
 							GTK_OBJECT(g_list_nth_data(glist,i+MENUFILE-1))));
