@@ -104,7 +104,7 @@ int main(int argc,char *argv[])
 	GdkPixmap *pixmap;
 	GtkAccelGroup *accel_group;
 	GtkStyle *style;
-	GtkWidget *menubar,*menu_item,*sub_menu;
+	GtkWidget *menu_bar, *menu_shell, *menu_item;
 	GtkWidget *handle,*text,*table,*toolbar,*vbox,*frame;
 	GtkItemFactoryEntry menu_items[]={
 {N_("/_File"),                       NULL,         NULL,            0,"<Branch>"},
@@ -317,10 +317,6 @@ int main(int argc,char *argv[])
 									(gpointer)&ftype[i].code,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL))
 				ftype[i].code=FALSE;
-			if (!profile_get_value(profile,section,"crlf",
-									(gpointer)&ftype[i].crlf,sizeof(gboolean),
-													PROFILE_VALUE_TYPE_BOOL))
-				ftype[i].crlf=FALSE;
 			if (!profile_get_value(profile,section,"eof",
 									(gpointer)&ftype[i].eof,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL))
@@ -349,6 +345,10 @@ int main(int argc,char *argv[])
 									(gpointer)&ftype[i].mline,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL))
 				ftype[i].mline=FALSE;
+			if (!profile_get_value(profile,section,"nline",
+									(gpointer)&ftype[i].nline,sizeof(gboolean),
+													PROFILE_VALUE_TYPE_BOOL))
+				ftype[i].nline=FALSE;
 			if (!profile_get_value(profile,section,"uline",
 									(gpointer)&ftype[i].uline,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL))
@@ -386,26 +386,13 @@ int main(int argc,char *argv[])
 	/* ե륿 */
 	if (ftnum<=0) {
 		ftnum=1;
-		ftype=g_malloc(ftnum*sizeof(FileType));
+		ftype = g_malloc0 (ftnum * sizeof (FileType));
 		ftype[0].text=g_strdup(_("All Files"));
 		ftype[0].ext=g_strdup("*");
 		ftype[0].margin=80;
 		ftype[0].tab=8;
 		ftype[0].associate=TRUE;
-		ftype[0].autoindent=FALSE;
-		ftype[0].code=FALSE;
-		ftype[0].crlf=FALSE;
-		ftype[0].eof=FALSE;
-		ftype[0].limit=FALSE;
-		ftype[0].overwrite=FALSE;
-		ftype[0].space=FALSE;
 		ftype[0].syscol=TRUE;
-		ftype[0].gline=FALSE;
-		ftype[0].mline=FALSE;
-		ftype[0].uline=FALSE;
-		ftype[0].vline=FALSE;
-		/* ե */
-		ftype[0].font_name=NULL;
 		/*  */
 		g_memmove(ftype[0].color,system_color,sizeof(GdkColor)*12);
 	}
@@ -471,7 +458,7 @@ int main(int argc,char *argv[])
 	gtk_item_factory_create_items(item_factory_menu,
 			sizeof(menu_items)/sizeof(GtkItemFactoryEntry),menu_items,NULL);
 	gtk_accel_group_attach(accel_group,GTK_OBJECT(window));
-	menubar=gtk_item_factory_get_widget(item_factory_menu,"<main>");
+	menu_bar = gtk_item_factory_get_widget (item_factory_menu, "<main>");
 	/* ġС */
 	toolbar=gtk_toolbar_new(GTK_ORIENTATION_HORIZONTAL,GTK_TOOLBAR_ICONS);
 	for (i=0;toolbar_items[i].name!=(gpointer)-1;i++)
@@ -501,7 +488,7 @@ int main(int argc,char *argv[])
 	vbox=gtk_vbox_new(FALSE,0);
 	handle=gtk_handle_box_new();
 	gtk_container_set_border_width(GTK_CONTAINER(handle),2);
-	gtk_container_add(GTK_CONTAINER(handle),menubar);
+	gtk_container_add (GTK_CONTAINER (handle), menu_bar);
 	gtk_box_pack_start(GTK_BOX(vbox),handle,FALSE,FALSE,0);
 	handle=gtk_handle_box_new();
 	gtk_container_set_border_width(GTK_CONTAINER(handle),2);
@@ -516,7 +503,8 @@ int main(int argc,char *argv[])
 	gtk_box_pack_end(GTK_BOX(vbox),text,FALSE,FALSE,0);
 	gtk_container_add(GTK_CONTAINER(window),vbox);
 	/* ե */
-	sub_menu=gtk_item_factory_get_widget(item_factory_menu,"<main>/File");
+	menu_shell = gtk_item_factory_get_widget (item_factory_menu,
+																"<main>/File");
 	for (i=0;i<history && history_files[i]!=NULL;i++) {
 		menu_item=gtk_menu_item_new_with_label(history_files[i]);
 		gtk_signal_connect(GTK_OBJECT(menu_item),"activate",
@@ -524,10 +512,11 @@ int main(int argc,char *argv[])
 		gtk_signal_connect(GTK_OBJECT(menu_item),"destroy",
 			GTK_SIGNAL_FUNC(signal_destroy_menu_history),history_files[i]);
 		gtk_object_set_user_data(GTK_OBJECT(menu_item),history_files[i]);
-		gtk_menu_insert(GTK_MENU(sub_menu),menu_item,i+MENUFILE-1);
+		gtk_menu_insert (GTK_MENU (menu_shell), menu_item, i + MENUFILE - 1);
 	}
 	if (i>0)
-		gtk_menu_insert(GTK_MENU(sub_menu),gtk_menu_item_new(),i+MENUFILE-1);
+		gtk_menu_insert (GTK_MENU (menu_shell), gtk_menu_item_new (),
+															i + MENUFILE - 1);
 	/*  */
 	timer_id=gtk_timeout_add(500,signal_timeout,NULL);
 
@@ -751,9 +740,6 @@ int main(int argc,char *argv[])
 			profile_set_value(profile,section,"code",
 									(gpointer)&ftype[i].code,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
-			profile_set_value(profile,section,"crlf",
-								(gpointer)&ftype[i].crlf,sizeof(gboolean),
-													PROFILE_VALUE_TYPE_BOOL);
 			profile_set_value(profile,section,"eof",
 									(gpointer)&ftype[i].eof,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
@@ -775,6 +761,9 @@ int main(int argc,char *argv[])
 			profile_set_value(profile,section,"mline",
 									(gpointer)&ftype[i].mline,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
+			profile_set_value(profile,section,"nline",
+								(gpointer)&ftype[i].nline,sizeof(gboolean),
+													PROFILE_VALUE_TYPE_BOOL);
 			profile_set_value(profile,section,"uline",
 									(gpointer)&ftype[i].uline,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
