@@ -35,10 +35,11 @@
 
 typedef struct FileType_Tag {
 	gint ft_id;					/* ե륿פID */
+	gint margin;				/* ޡο */
+	gint tab;					/* ֤ο */
 	gboolean autoindent;		/* TRUE:ư */
 	gboolean associate;			/* TRUE:ϢŤ */
 	gboolean code;				/* TRUE:֤Υɤɽ */
-	gboolean crlf;				/* TRUE:ԥɤɽ */
 	gboolean eof;				/* TRUE:1Ahե˽񤭲ä */
 	gboolean limit;				/* TRUE:ޡޤ֤ */
 	gboolean overwrite;			/* TRUE:ե񤭤Ȥ˳ǧ */
@@ -46,12 +47,11 @@ typedef struct FileType_Tag {
 	gboolean syscol;			/* TRUE:ƥ࿧Ȥ */
 	gboolean gline;				/* TRUE:åɽ */
 	gboolean mline;				/* TRUE:ޡɽ */
+	gboolean nline;				/* TRUE:ԥɤɽ */
 	gboolean uline;				/* TRUE:ֲɽ */
 	gboolean vline;				/* TRUE:ֽɽ */
-	gchar *text,*ext;			/* ̾,ĥ */
 	gchar *font_name;			/* ե̾ */
-	gint margin;				/* ޡο */
-	gint tab;					/* ֤ο */
+	gchar *text,*ext;			/* ̾,ĥ */
 	GdkColor color[12];			/*  */
 } FileType;
 typedef struct TmaidHistory_Tag {
@@ -70,33 +70,17 @@ typedef struct LineBuffer_Tag {
 typedef struct TmaidWindow_Tag {
 	gboolean create;			/* TRUE:,FALSE:¸ե */
 	gboolean edit;				/* TRUE:ԽѤ,FALSE:̤Խ */
-	gboolean autoindent;		/* TRUE:ư */
-	gboolean code;				/* TRUE:֤Υɤɽ */
-	gboolean crlf;				/* TRUE:ԥɤɽ */
-	gboolean eof;				/* TRUE:1Ahե˽񤭲ä */
-	gboolean limit;				/* TRUE:ޡޤ֤ */
-	gboolean overwrite;			/* TRUE:ե񤭤Ȥ˳ǧ */
-	gboolean space;				/* TRUE:ڡ򳥿λͳѤɽ */
-	gboolean syscol;			/* TRUE:ƥ࿧Ȥ */
-	gboolean gline;				/* TRUE:åɽ */
-	gboolean mline;				/* TRUE:ޡɽ */
-	gboolean uline;				/* TRUE:ֲɽ */
-	gboolean vline;				/* TRUE:ֽɽ */
 	gchar *file;				/* ե̾ */
-	gchar *font_name;			/* ե̾ */
-	gint ft_id;					/* ե륿פID(-1:̵°) */
 	gint font_width;			/* եȤβ */
 	gint font_height;			/* եȤι⤵ */
 	gint font_ascent;			/* եȤΥȤι⤵ */
-	gint margin;				/* ޡο */
 	gint max;					/* Կ */
 	gint off;					/* startȤ */
 	gint same;					/* -1:ʣʤ,0:ֹ */
-	gint tab;					/* ֤ο */
 	guint timer_id;				/* ѥ */
+	FileType ft;				/* ե륿 */
 	LineBuffer *start;			/* ꥹ */
 	TmaidHistory *undo,*redo;	/* Խ */
-	GdkColor color[12];			/*  */
 	GdkFont *font;				/* ե */
 #ifdef USE_XIM
 	GdkIC *ic;					/* XIM */
