@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -40,8 +40,8 @@ static void valchr_dialog_changed(GtkWidget *widget,gpointer user_data)
 
 	misc_str_to_val(&value,gtk_entry_get_text(GTK_ENTRY(widget)),
 															valchr_base,FALSE);
-	gtk_widget_set_sensitive(button0,0<=value && value<=255
-												&& charset->length[value]==1);
+	gtk_widget_set_sensitive (button0, 0 <= value && value <= 255
+											&& charset_length (value) == 1);
 }
 
 
@@ -67,7 +67,7 @@ static void valchr_dialog_clicked_ok(GtkWidget *widget,gchar *valchr)
 
 	misc_str_to_val(&value,gtk_entry_get_text(GTK_ENTRY(entry)),
 															valchr_base,FALSE);
-	*valchr=valchr_default=valchr_default=value;
+	*valchr = valchr_default = value;
 	gtk_widget_destroy(dialog);
 	valchr_clicked_ok=TRUE;
 }
@@ -80,7 +80,7 @@ static void valchr_dialog_activate(GtkWidget *widget,gchar *valchr)
 
 	misc_str_to_val(&value,gtk_entry_get_text(GTK_ENTRY(widget)),
 															valchr_base,FALSE);
-	if (0<=value && value<=255 && charset->length[value]==1)
+	if (0 <= value && value <= 255 && charset_length (value) == 1)
 		valchr_dialog_clicked_ok(widget,valchr);
 }
 
